﻿using System;
using System.Collections;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using System.Windows.Threading;
using Telerik.Charting;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.ChartView;

namespace sl_ChartView_647814
{
    public partial class MainPage : UserControl
    {
        private DataPoint currentDataPoint;
        private RadToolTip tooltip = new RadToolTip();
        private Point mousePosition;
        private DispatcherTimer timer = new DispatcherTimer();

        public MainPage()
        {
            InitializeComponent();

            this.timer.Tick += this.timer_Tick;
            this.timer.Interval = new TimeSpan(0, 0, 0, 0, 300);
        }

        private void timer_Tick(object sender, EventArgs e)
        {
            this.ShowToolTip();
        }

        private void RadCartesianChart_MouseMove(object sender, MouseEventArgs e)
        {
            this.mousePosition = e.GetPosition(this.chart1);
            DataPoint newDataPoint = null;
            foreach (var series in this.chart1.Series.OrderByDescending(s => Canvas.GetZIndex(s)))
            {
                newDataPoint = GetHoveredDataPoint(series);
                if (newDataPoint != null)
                {
                    break;
                }
            }

            this.HandleNewDataPoint(newDataPoint);
        }

        private void RadCartesianChart_MouseLeave(object sender, MouseEventArgs e)
        {
            this.OnMouseLeaveDataPoint();
        }

        private DataPoint GetHoveredDataPoint(CartesianSeries series)
        {
            IEnumerable dataPoints = null;
            if (series is CategoricalSeries)
            {
                dataPoints = ((CategoricalSeries)series).DataPoints;
            }

            foreach (DataPoint dp in dataPoints)
            {
                if (dp.LayoutSlot.Contains(this.mousePosition.X - series.Chart.PanOffset.X, this.mousePosition.Y - series.Chart.PanOffset.Y))
                {
                    return dp;
                }
            }

            return null;
        }

        private void HandleNewDataPoint(DataPoint newDataPoint)
        {
            if (newDataPoint != this.currentDataPoint)
            {
                this.OnMouseLeaveDataPoint();
                this.OnMouseEnterDataPoint(newDataPoint);
            }
        }

        private void OnMouseEnterDataPoint(DataPoint newDataPoint)
        {
            if (newDataPoint != null)
            {
                this.currentDataPoint = newDataPoint;
                this.timer.Start();
            }
        }

        private void OnMouseLeaveDataPoint()
        {
            this.timer.Stop();
            this.currentDataPoint = null;
            this.HideToolTip();
        }

        private void ShowToolTip()
        {
            this.timer.Start();
            this.tooltip.Content = this.currentDataPoint;
            this.tooltip.ContentTemplate = ((ChartSeries)this.currentDataPoint.Presenter).TooltipTemplate;
            this.tooltip.PlacementTarget = this.chart1;
            this.tooltip.HorizontalOffset = this.mousePosition.X;
            this.tooltip.VerticalOffset = this.mousePosition.Y;
            this.tooltip.IsOpen = true;
        }

        private void HideToolTip()
        {
            this.tooltip.IsOpen = false;
        }
    }
}
